summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorXavier Claessens <xavier.claessens@collabora.co.uk>2013-09-27 14:04:37 -0400
committerGuillaume Desmottes <guillaume.desmottes@collabora.co.uk>2013-10-01 15:45:21 +0200
commit51f72228e4ef4fda0475dc3af52caad1cb320842 (patch)
tree66a61b2fdc0e456c8896d7d9aa87935f19ecb720
parentd0e14a0064e0ff6bee3caa7b034fd8bd44073151 (diff)
downloadtelepathy-logger-51f72228e4ef4fda0475dc3af52caad1cb320842.tar.gz
Rename org.freedesktop.Telepathy to im.telepathy1
-rw-r--r--data/Logger.Call.client.in12
-rw-r--r--data/Logger.Observer.client.in4
-rw-r--r--data/Logger.Recover.client.in2
-rw-r--r--data/Logger.Text.client.in12
-rw-r--r--data/Makefile.am4
-rw-r--r--data/im.telepathy1.Client.Logger.service.in (renamed from data/org.freedesktop.Telepathy.Logger.service.in)2
-rw-r--r--data/im.telepathy1.Logger.service.in (renamed from data/org.freedesktop.Telepathy.Client.Logger.service.in)2
-rw-r--r--doc/templates/interface.html4
-rw-r--r--extensions/Logger.xml10
-rw-r--r--telepathy-logger/dbus-service-internal.h4
-rw-r--r--telepathy-logger/observer-internal.h4
-rw-r--r--telepathy-logger/observer.c8
-rw-r--r--tests/constants.h2
-rw-r--r--tests/dbus/test-log-manager.c4
-rw-r--r--tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user3@collabora.co.uk/20100113.call.log2
-rw-r--r--tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user4@collabora.co.uk/20100113.call.log6
-rw-r--r--tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user5@collabora.co.uk/20100113.call.log2
-rw-r--r--tests/logs/purple/irc/user@irc.freenode.net/#telepathy.chat/2010-11-30.124947+0000GMT.html2
-rw-r--r--tools/doc-generator.xsl2
19 files changed, 44 insertions, 44 deletions
diff --git a/data/Logger.Call.client.in b/data/Logger.Call.client.in
index eef1a6c..0ae64b9 100644
--- a/data/Logger.Call.client.in
+++ b/data/Logger.Call.client.in
@@ -1,8 +1,8 @@
-[org.freedesktop.Telepathy.Client.Observer.ObserverChannelFilter 3]
-org.freedesktop.Telepathy.Channel.ChannelType s=org.freedesktop.Telepathy.Channel.Type.Call1
-org.freedesktop.Telepathy.Channel.TargetHandleType u=1
+[im.telepathy1.Client.Observer.ObserverChannelFilter 3]
+im.telepathy1.Channel.ChannelType s=im.telepathy1.Channel.Type.Call1
+im.telepathy1.Channel.TargetHandleType u=1
-[org.freedesktop.Telepathy.Client.Observer.ObserverChannelFilter 4]
-org.freedesktop.Telepathy.Channel.ChannelType s=org.freedesktop.Telepathy.Channel.Type.Call1
-org.freedesktop.Telepathy.Channel.TargetHandleType u=2
+[im.telepathy1.Client.Observer.ObserverChannelFilter 4]
+im.telepathy1.Channel.ChannelType s=im.telepathy1.Channel.Type.Call1
+im.telepathy1.Channel.TargetHandleType u=2
diff --git a/data/Logger.Observer.client.in b/data/Logger.Observer.client.in
index e3cff68..a1c9dfa 100644
--- a/data/Logger.Observer.client.in
+++ b/data/Logger.Observer.client.in
@@ -1,3 +1,3 @@
-[org.freedesktop.Telepathy.Client]
-Interfaces=org.freedesktop.Telepathy.Client.Observer
+[im.telepathy1.Client]
+Interfaces=im.telepathy1.Client.Observer
diff --git a/data/Logger.Recover.client.in b/data/Logger.Recover.client.in
index bd1766f..f18cd72 100644
--- a/data/Logger.Recover.client.in
+++ b/data/Logger.Recover.client.in
@@ -1,2 +1,2 @@
-[org.freedesktop.Telepathy.Client.Observer]
+[im.telepathy1.Client.Observer]
Recover=true
diff --git a/data/Logger.Text.client.in b/data/Logger.Text.client.in
index 562b040..eae677c 100644
--- a/data/Logger.Text.client.in
+++ b/data/Logger.Text.client.in
@@ -1,8 +1,8 @@
-[org.freedesktop.Telepathy.Client.Observer.ObserverChannelFilter 0]
-org.freedesktop.Telepathy.Channel.ChannelType s=org.freedesktop.Telepathy.Channel.Type.Text
-org.freedesktop.Telepathy.Channel.TargetHandleType u=1
+[im.telepathy1.Client.Observer.ObserverChannelFilter 0]
+im.telepathy1.Channel.ChannelType s=im.telepathy1.Channel.Type.Text
+im.telepathy1.Channel.TargetHandleType u=1
-[org.freedesktop.Telepathy.Client.Observer.ObserverChannelFilter 1]
-org.freedesktop.Telepathy.Channel.ChannelType s=org.freedesktop.Telepathy.Channel.Type.Text
-org.freedesktop.Telepathy.Channel.TargetHandleType u=2
+[im.telepathy1.Client.Observer.ObserverChannelFilter 1]
+im.telepathy1.Channel.ChannelType s=im.telepathy1.Channel.Type.Text
+im.telepathy1.Channel.TargetHandleType u=2
diff --git a/data/Makefile.am b/data/Makefile.am
index 1e2d780..ac47ec7 100644
--- a/data/Makefile.am
+++ b/data/Makefile.am
@@ -7,8 +7,8 @@ gsettings_SCHEMAS = $(gsettings_files:.xml.in=.xml)
servicefiledir = $(datadir)/dbus-1/services
servicefile_in_files = \
- org.freedesktop.Telepathy.Client.Logger.service.in \
- org.freedesktop.Telepathy.Logger.service.in
+ im.telepathy1.Client.Logger.service.in \
+ im.telepathy1.Logger.service.in
servicefile_DATA = $(servicefile_in_files:.service.in=.service)
%.service: %.service.in Makefile
$(AM_V_GEN)sed -e "s|[@]libexecdir[@]|$(libexecdir)|" $< > $@
diff --git a/data/org.freedesktop.Telepathy.Logger.service.in b/data/im.telepathy1.Client.Logger.service.in
index 684fb90..cf6f348 100644
--- a/data/org.freedesktop.Telepathy.Logger.service.in
+++ b/data/im.telepathy1.Client.Logger.service.in
@@ -1,3 +1,3 @@
[D-BUS Service]
-Name=org.freedesktop.Telepathy.Logger
+Name=im.telepathy1.Client.Logger
Exec=@libexecdir@/telepathy-logger
diff --git a/data/org.freedesktop.Telepathy.Client.Logger.service.in b/data/im.telepathy1.Logger.service.in
index a5e7251..118e00d 100644
--- a/data/org.freedesktop.Telepathy.Client.Logger.service.in
+++ b/data/im.telepathy1.Logger.service.in
@@ -1,3 +1,3 @@
[D-BUS Service]
-Name=org.freedesktop.Telepathy.Client.Logger
+Name=im.telepathy1.Logger
Exec=@libexecdir@/telepathy-logger
diff --git a/doc/templates/interface.html b/doc/templates/interface.html
index c159bf5..42ad0ce 100644
--- a/doc/templates/interface.html
+++ b/doc/templates/interface.html
@@ -326,7 +326,7 @@
<a name="tpproperties"></a>
<h1>Telepathy Properties</h1>
<div>
- Accessed using the org.freedesktop.Telepathy.Properties interface.
+ Accessed using the im.telepathy1.Properties interface.
</div>
#for $property in $interface.tpproperties
<div class="inset tpproperty">
@@ -351,7 +351,7 @@
<h1>Contact Attributes</h1>
<div>
Attributes that a contact can have, accessed with the
- org.freedesktop.Telepathy.Connection.Interface.Contacts interface.
+ im.telepathy1.Connection.Interface.Contacts interface.
</div>
#for $token in $interface.contact_attributes
<div class="inset contact-attribute">
diff --git a/extensions/Logger.xml b/extensions/Logger.xml
index cf5e067..ecfcdf1 100644
--- a/extensions/Logger.xml
+++ b/extensions/Logger.xml
@@ -17,7 +17,7 @@ Lesser General Public License for more details.</p>
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</p>
</tp:license>
- <interface name="org.freedesktop.Telepathy.Logger.DRAFT"
+ <interface name="im.telepathy1.Logger.DRAFT"
tp:causes-havoc="experimental">
<tp:added version="0.3">(as a draft)</tp:added>
@@ -57,8 +57,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</
<tp:docstring>
Add a contact's designation as a favourite. This method may not be
called until the service is ready. See the <tp:dbus-ref
- namespace="org.freedesktop.Telepathy.Logger.DRAFT">FavouriteContactsReady</tp:dbus-ref> signal and <tp:dbus-ref
- namespace="org.freedesktop.Telepathy.Logger.DRAFT">FavouriteContactsIsReady</tp:dbus-ref> property.
+ namespace="im.telepathy1.Logger.DRAFT">FavouriteContactsReady</tp:dbus-ref> signal and <tp:dbus-ref
+ namespace="im.telepathy1.Logger.DRAFT">FavouriteContactsIsReady</tp:dbus-ref> property.
</tp:docstring>
</method>
@@ -79,8 +79,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.</
<tp:docstring>
Remove a contact's designation as a favourite. This method may not be
called until the service is ready. See the <tp:dbus-ref
- namespace="org.freedesktop.Telepathy.Logger.DRAFT">FavouriteContactsReady</tp:dbus-ref> signal and <tp:dbus-ref
- namespace="org.freedesktop.Telepathy.Logger.DRAFT">FavouriteContactsIsReady</tp:dbus-ref> property.
+ namespace="im.telepathy1.Logger.DRAFT">FavouriteContactsReady</tp:dbus-ref> signal and <tp:dbus-ref
+ namespace="im.telepathy1.Logger.DRAFT">FavouriteContactsIsReady</tp:dbus-ref> property.
</tp:docstring>
</method>
diff --git a/telepathy-logger/dbus-service-internal.h b/telepathy-logger/dbus-service-internal.h
index d3d0dda..b2dc657 100644
--- a/telepathy-logger/dbus-service-internal.h
+++ b/telepathy-logger/dbus-service-internal.h
@@ -27,9 +27,9 @@
#include <telepathy-logger/log-manager.h>
#define TPL_DBUS_SRV_WELL_KNOWN_BUS_NAME \
- "org.freedesktop.Telepathy.Logger"
+ "im.telepathy1.Logger"
#define TPL_DBUS_SRV_OBJECT_PATH \
- "/org/freedesktop/Telepathy/Logger"
+ "/im.telepathy1/Logger"
G_BEGIN_DECLS
diff --git a/telepathy-logger/observer-internal.h b/telepathy-logger/observer-internal.h
index 5be5526..a0f1acf 100644
--- a/telepathy-logger/observer-internal.h
+++ b/telepathy-logger/observer-internal.h
@@ -26,9 +26,9 @@
#include <telepathy-glib/telepathy-glib.h>
#define TPL_OBSERVER_WELL_KNOWN_BUS_NAME \
- "org.freedesktop.Telepathy.Client.Logger"
+ "im.telepathy1.Client.Logger"
#define TPL_OBSERVER_OBJECT_PATH \
- "/org/freedesktop/Telepathy/Client/Logger"
+ "/im.telepathy1/Client/Logger"
G_BEGIN_DECLS
diff --git a/tests/constants.h b/tests/constants.h
index 7507072..7eb4b9e 100644
--- a/tests/constants.h
+++ b/tests/constants.h
@@ -1,2 +1,2 @@
-#define ACCOUNT_PATH "/org/freedesktop/Telepathy/Account/gabble/jabber/cosimo_2ealfarano_40collabora_2eco_2euk0"
+#define ACCOUNT_PATH "/im.telepathy1/Account/gabble/jabber/cosimo_2ealfarano_40collabora_2eco_2euk0"
#define ID "echo@test.collabora.co.uk"
diff --git a/tests/dbus/test-log-manager.c b/tests/dbus/test-log-manager.c
index 11edfb3..6bd7b66 100644
--- a/tests/dbus/test-log-manager.c
+++ b/tests/dbus/test-log-manager.c
@@ -650,7 +650,7 @@ test_ignorelist (TestCaseFixture *fixture,
event1 = g_object_new (TPL_TYPE_TEXT_EVENT,
"account", fixture->account,
- "channel-path", "org.freedesktop.Telepathy.channel.path",
+ "channel-path", "im.telepathy1.channel.path",
"receiver", receiver,
"sender", sender,
"timestamp", (gint64) 1,
@@ -663,7 +663,7 @@ test_ignorelist (TestCaseFixture *fixture,
event2 = g_object_new (TPL_TYPE_TEXT_EVENT,
"account", fixture->account,
- "channel-path", "org.freedesktop.Telepathy.channel.path",
+ "channel-path", "im.telepathy1.channel.path",
"receiver", sender,
"sender", receiver,
"timestamp", (gint64) 2,
diff --git a/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user3@collabora.co.uk/20100113.call.log b/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user3@collabora.co.uk/20100113.call.log
index 38e425a..7ab442a 100644
--- a/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user3@collabora.co.uk/20100113.call.log
+++ b/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user3@collabora.co.uk/20100113.call.log
@@ -1,5 +1,5 @@
<?xml version='1.0' encoding='utf-8'?>
<?xml-stylesheet type="text/xsl" href="empathy-log.xsl"?>
<log>
-<call time='20100113T23:11:15' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='12' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='org.freedesktop.Telepathy.Error.Cancelled' />
+<call time='20100113T23:11:15' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='12' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='im.telepathy1.Error.Cancelled' />
</log>
diff --git a/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user4@collabora.co.uk/20100113.call.log b/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user4@collabora.co.uk/20100113.call.log
index 2a0511c..c5f65a5 100644
--- a/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user4@collabora.co.uk/20100113.call.log
+++ b/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user4@collabora.co.uk/20100113.call.log
@@ -1,7 +1,7 @@
<?xml version='1.0' encoding='utf-8'?>
<?xml-stylesheet type="text/xsl" href="empathy-log.xsl"?>
<log>
-<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='1' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='org.freedesktop.Telepathy.Error.Cancelled' />
-<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='2' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='org.freedesktop.Telepathy.Error.Cancelled' />
-<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='3' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='org.freedesktop.Telepathy.Error.Cancelled' />
+<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='1' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='im.telepathy1.Error.Cancelled' />
+<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='2' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='im.telepathy1.Error.Cancelled' />
+<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='3' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='im.telepathy1.Error.Cancelled' />
</log>
diff --git a/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user5@collabora.co.uk/20100113.call.log b/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user5@collabora.co.uk/20100113.call.log
index 50b4e34..34e5e6a 100644
--- a/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user5@collabora.co.uk/20100113.call.log
+++ b/tests/logs/TpLogger/logs/gabble_jabber_user_40collabora_2eco_2euk/user5@collabora.co.uk/20100113.call.log
@@ -1,5 +1,5 @@
<?xml version='1.0' encoding='utf-8'?>
<?xml-stylesheet type="text/xsl" href="empathy-log.xsl"?>
<log>
-<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='1' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='org.freedesktop.Telepathy.Error.Cancelled' />
+<call time='20100113T17:48:01' id='user@collabora.co.uk' name='Nicolas1' isuser='false' token='' duration='1' actor='user@collabora.co.uk' actortype='contact' actorname='User1' actortoken='' reason='user-requested' detail='im.telepathy1.Error.Cancelled' />
</log>
diff --git a/tests/logs/purple/irc/user@irc.freenode.net/#telepathy.chat/2010-11-30.124947+0000GMT.html b/tests/logs/purple/irc/user@irc.freenode.net/#telepathy.chat/2010-11-30.124947+0000GMT.html
index 8bac4a7..f024a0c 100644
--- a/tests/logs/purple/irc/user@irc.freenode.net/#telepathy.chat/2010-11-30.124947+0000GMT.html
+++ b/tests/logs/purple/irc/user@irc.freenode.net/#telepathy.chat/2010-11-30.124947+0000GMT.html
@@ -61,7 +61,7 @@
<font color="#A82F2F"><font size="2">(15:15:10)</font> <b>wjt:</b></font> i guess the collabora xmpp server does privacy list-based invisibility, so it&apos;s only doing what i asked<br/>
<font color="#A82F2F"><font size="2">(15:16:50)</font> <b>cassidy:</b></font> wjt, how can you test if you are actually invisible? The account presence is always sync with your real status?<br/>
<font color="#A82F2F"><font size="2">(15:17:26)</font> <b>cassidy:</b></font> (I like this ghost icon :)<br/>
-<font color="#A82F2F"><font size="2">(15:17:28)</font> <b>wjt:</b></font> http://telepathy.freedesktop.org/spec/Account.html#org.freedesktop.Telepathy.Account.CurrentPresence is based on what the CM says it is<br/>
+<font color="#A82F2F"><font size="2">(15:17:28)</font> <b>wjt:</b></font> http://telepathy.freedesktop.org/spec/Account.html#im.telepathy1.Account.CurrentPresence is based on what the CM says it is<br/>
<font color="#A82F2F"><font size="2">(15:17:37)</font> <b>wjt:</b></font> and that&apos;s what shows up in the account dialog<br/>
<font color="#A82F2F"><font size="2">(15:17:46)</font> <b>wjt:</b></font> what does the ghost look like? I use a different theme.<br/>
<font color="#A82F2F"><font size="2">(15:20:40)</font> <b>cassidy:</b></font> wjt, http://people.collabora.co.uk/~cassidy/status.jpg<br/>
diff --git a/tools/doc-generator.xsl b/tools/doc-generator.xsl
index 76fc969..90090d2 100644
--- a/tools/doc-generator.xsl
+++ b/tools/doc-generator.xsl
@@ -276,7 +276,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
<xsl:when test="tp:property">
<h2 xmlns="http://www.w3.org/1999/xhtml">Telepathy Properties:</h2>
<p xmlns="http://www.w3.org/1999/xhtml">Accessed using the
- <a href="#org.freedesktop.Telepathy.Properties">Telepathy
+ <a href="#im.telepathy1.Properties">Telepathy
Properties</a> interface.</p>
<dl xmlns="http://www.w3.org/1999/xhtml">
<xsl:apply-templates select="tp:property"/>
diff --git a/telepathy-logger/observer.c b/telepathy-logger/observer.c
index c4be723..7307ffb 100644
--- a/telepathy-logger/observer.c
+++ b/telepathy-logger/observer.c
@@ -41,7 +41,7 @@
* @see_also: #TpSvcClientObserver
*
* The Telepathy Logger's Observer implements
* org.freedesktop.Telepathy.Client.Observer DBus interface and is called by
* the Channel Dispatcher when a new channel is created, in order to log
* received signals.
*
@@ -52,7 +52,7 @@
* TplObserver:
*
* The Telepathy Logger's Observer implements
* org.freedesktop.Telepathy.Client.Observer DBus interface and is called by
* the Channel Dispatcher when a new channel is created, in order to log
* received signals using its #LogManager.
*
@@ -243,7 +243,7 @@ _tpl_observer_init (TplObserver *self)
tp_base_client_take_observer_filter (TP_BASE_CLIENT (self),
tp_asv_new (
TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
- "org.freedesktop.Telepathy.Channel.Type.Call1",
+ "im.telepathy1.Channel.Type.Call1",
TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
TP_HANDLE_TYPE_CONTACT,
NULL));
@@ -252,7 +252,7 @@ _tpl_observer_init (TplObserver *self)
tp_base_client_take_observer_filter (TP_BASE_CLIENT (self),
tp_asv_new (
TP_PROP_CHANNEL_CHANNEL_TYPE, G_TYPE_STRING,
- "org.freedesktop.Telepathy.Channel.Type.Call1",
+ "im.telepathy1.Channel.Type.Call1",
TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT,
TP_HANDLE_TYPE_ROOM,
NULL));
@@ -41,7 +41,7 @@
*
* The Telepathy Logger's Observer implements
- * org.freedesktop.Telepathy.Client.Observer DBus interface and is called by
+ * im.telepathy1.Client.Observer DBus interface and is called by
* the Channel Dispatcher when a new channel is created, in order to log
* received signals.
@@ -52,7 +52,7 @@
*
* The Telepathy Logger's Observer implements
- * org.freedesktop.Telepathy.Client.Observer DBus interface and is called by
+ * im.telepathy1.Client.Observer DBus interface and is called by
* the Channel Dispatcher when a new channel is created, in order to log
* received signals using its #LogManager.